aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/content.ts
diff options
context:
space:
mode:
Diffstat (limited to 'src/content.ts')
-rw-r--r--src/content.ts4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/content.ts b/src/content.ts
index b1db2c76..e0f0572e 100644
--- a/src/content.ts
+++ b/src/content.ts
@@ -1318,9 +1318,11 @@ function openInfoMenu() {
let htmlData = xmlhttp.responseText;
// Hack to replace head data (title, favicon)
htmlData = htmlData.replace(/<head>[\S\s]*<\/head>/gi, "");
// Hack to replace body tag with div
htmlData = htmlData.replace(/<body/gi, "<div");
htmlData = htmlData.replace(/<\/body/gi, "</div");
+ htmlData = htmlData.replace(/<html/gi, "<div");
+ htmlData = htmlData.replace(/<\/html/gi, "</div");
popup.innerHTML = htmlData;
@@ -1318,9 +1318,11 @@ function openInfoMenu() {
// Hack to replace head data (title, favicon)
htmlData = htmlData.replace(/<head>[\S\s]*<\/head>/gi, "");
- // Hack to replace body tag with div
+ // Hack to replace body and html tag with div
htmlData = htmlData.replace(/<body/gi, "<div");
htmlData = htmlData.replace(/<\/body/gi, "</div");